<?php require_once( 'couch/cms.php' ); ?>
<cms:template title="Download System" clonable="1" dynamic_folders="1">
	<!-- Title (k_page_title): Can be used as one of the required attributes -->
	<!-- Start: Editable regions for the attributes -->
	<cms:editable name="description" label="Description" type="richtext" order="1" />
	<cms:editable name="author" label="Author" type="text" order="2" />
	<cms:editable name="publication_date" label="Publication Date" type="datetime" format="Y-m-d" order="3" />
	<!-- End: Editable regions for the attributes -->
	<!-- Start: Editable region for the downloadable file -->
	<cms:editable name="file_to_download" label="Upload the file" desc="This file will be downloaded from the front end" type="securefile" allowed_ext="jpg,jpeg,png,doc,docx,ppt,pptx,xls,xlsx,pdf,zip" max_size="5120" order="4" />
	<!-- End: Editable region for the downloadable file -->
</cms:template>
<!DOCTYPE html>
<html>
	<head>
		<meta charset="utf-8">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<title>Download System</title>
		<!-- Bootstrap CSS CDN: For the page structuring -->
		<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet" >
		<!-- Fontawesome CSS CDN: For the file extension icon display -->
		<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.7.2/css/all.css"/>
	</head>
	<body>
		<main>
			<section id="downloadable_files" class="my-5">
				<div class="container">
					<div class="row">
						<!-- Start: Category list generated using the dynamic_folders -->
						<div class="col-12 col-md-3 mb-5">
							<h4 class="mb-2">Categories</h4>
							<div class="list-group shadow">
								<cms:folders masterpage=k_template_name hierarchical="1" >
									<cms:set current_folder_id="<cms:gpc 'f' method='get' />" scope='global' />
									<a href="<cms:show k_folder_link />" class="list-group-item d-flex justify-content-between align-items-start list-group-item-action <cms:if k_folder_id=current_folder_id>active</cms:if>">
										<div class="me-auto">
											<cms:if k_folder_parentid = '-1' >
												<div class="fw-bold"><cms:show k_folder_title /> [<cms:show k_level />]</div>
											<cms:else />
												<div class="ms-3 fw-bold"><cms:show k_folder_title /> [<cms:show k_level />]</div>
											</cms:if>
										</div>
										<span class="badge text-bg-warning rounded-pill"><cms:show k_folder_pagecount /></span>
									</a>
								</cms:folders>
							</div>
						</div>
						<!-- End: Category list generated using the dynamic_folders -->

						<!-- Start: Display Pages in fodlers or Display files in categories -->
						<div class="col-12 col-md-9 mb-5">
							<cms:if k_is_home >
								<!-- Rather than displaying a host of downloadable files we are displaying a message here to perform an action -->
								<div class="alert alert-info shadow">
									Select a category to view the files available for download under that category.
								</div>
							<cms:else_if k_is_folder />
								<div class="alert alert-light mb-4">
								    <a href="<cms:link 'sample-download.php' />">Home</a> <i class="fa-solid fa-angles-right"></i> <cms:breadcrumbs separator='&nbsp;<i class="fa-solid fa-angles-right"></i>&nbsp;' />				
								</div>
								<cms:if k_folder_immediate_children >
							        <h5>Sub Categories</h5>
							        <div class="row">
		    					        <cms:folders masterpage=k_template_name childof=k_folder_name depth='1' >
		    					        	<div class="col-12 col-md-4 text-center mb-4">
			    					        	<a href="<cms:show k_folder_link />" style="text-decoration: none;">
			    					        		<div class="card shadow">
			    					        			<div class="card-body">
			    					        				<h6><cms:show k_folder_title /></h6>
			    					        			</div>
			    					        		</div>
			    					        	</a>
			    					        </div>
		    							</cms:folders>
		    						</div>
		    					<cms:else />
		    						<h5>Sub Categories</h5>
							        <div class="row">
		    					        <div class="col-12 col-md-4 text-center mb-4">
		    					        	<div class="card shadow">
	    					        			<div class="card-body">
	    					        				<h6>No sub categories here</h6>
	    					        			</div>
	    					        		</div>
		    					        </div>
		    					    </div>
	    						</cms:if>
								<div class="card shadow">
									<div class="card-body">
										<h5 class="card-title">File(s) available for download</h5>
										<h6 class="card-subtitle text-muted">Downloadable files list with attributes of each file.</h6>
									</div>
									<table class="table">
										<thead>
											<tr>
												<th class="text-center" width="50px">
													#
												</th>
												<th width="*">
													File Details
												</th>
												<th class="text-center" width="120px">
													Download
												</th>
											</tr>
										</thead>
										<tbody>
											<cms:pages masterpage=k_template_name order="desc" folder=k_folder_name include_subfolders='0'>
											<cms:no_results>
											<tr>
												<td colspan='3' class="text-center">
													- No record found -
												</td>
											</tr>
											</cms:no_results>
											<tr>
												<td class="text-center">
													<!-- Displays sequential serial number -->
													<cms:show k_absolute_count />
												</td>
												<td>
													<!-- Start: File Attributes -->
													<div>
														<cms:show k_page_title />
													</div>
													<div>
														<small class="text-muted">
															<cms:show description />
														</small>
													</div>
													<div>
														<small>
															Author: <cms:show author />
														</small>
													</div>
													<div>
														<small>
															Published On: <cms:date publication_date format='M d, Y' />
														</small>
													</div>
													<!-- End: File Attributes -->
												</td>
												<td class="text-center align-middle">
													<!-- Start: Download Link -->
													<cms:show_securefile 'file_to_download' >
													<cms:set my_file_link = "<cms:cloak_url  file_id force_download='1' />" />
													<a href="<cms:show my_file_link />" class="btn btn-outline-dark p-3" >
														<cms:if (file_ext eq 'jpg' || file_ext eq 'jpeg' || file_ext eq 'png')>
															<i class="fa-regular fa-image fa-lg"></i>
														<cms:else_if file_ext eq 'pdf' />
															<i class="fa-regular fa-file-pdf fa-lg"></i>
														<cms:else_if (file_ext eq 'doc' || file_ext eq 'docx') />
															<i class="fa-regular fa-file-word fa-lg"></i>
														<cms:else_if (file_ext eq 'ppt' || file_ext eq 'pptx') />
															<i class="fa-regular fa-file-powerpoint fa-lg"></i>
														<cms:else_if (file_ext eq 'xls' || file_ext eq 'xlsx') />
															<i class="fa-regular fa-file-excel fa-lg"></i>
														<cms:else />
															<i class="fa-regular fa-file-zipper fa-lg"></i>
														</cms:if>
													</a>
													</cms:show_securefile>
													<!-- Start: Download Link -->
												</td>
											</tr>
											</cms:pages>
										</tbody>
									</table>
								</div>
							</cms:if>
						</div>
						<!-- End: Display Pages in fodlers or Display files in categories -->
					</div>
				</div>
			</section>
		</main>
	</body>
</html>
<?php COUCH::invoke(); ?>